@@ -1,5 +1,4 @@
 import requests
-
 from django.utils.crypto import get_random_string
 
 
@@ -15,8 +14,12 @@ class OAuth:
         response = requests.get(
             sf_id_url, headers={"Authorization": f"Bearer {access_token}"}
         )
+
+        assert (
+            response.status_code == 200
+        ), f"Could not retrieve user from Salesforce: {response.reason}"
         return response.json()
-    
+
     @property
     def salesforce_user(self):
         if not self._salesforce_user:
@@ -54,11 +57,15 @@ class OAuth:
     @property
     def access_token(self):
         return self.token_data.get("access_token")
-    
+
     @property
     def refresh_token(self):
         return self.token_data.get("refresh_token")
 
+    @property
+    def issued_at(self):
+        return self.token_data.get("issued_at")
+
     @property
     def password(self):
         """
